@@ -1,7 +1,5 @@
 package Kwiki::Display;
-use strict;
-use warnings;
-use Kwiki::Plugin '-Base';
+use Kwiki::Plugin -Base;
 use mixin 'Kwiki::Installer';
 
 const config_file => 'display.yaml';
@@ -28,20 +26,19 @@ sub display {
     my $page = $self->pages->current;
     my $page_title = $page->title;
     my $page_uri = $page->uri;
-    return $self->redirect("action=edit&page_id=$page_uri")
-      unless $page->exists;
+    return $self->redirect("action=edit&page_name=$page_uri")
+      if not($page->exists) and $self->have_plugin('edit');
     my $script = $self->config->script_name;
     my $screen_title = $self->hub->have_plugin('search')
     ? "<a href=\"$script?action=search&search_term=$page_uri\">$page_title</a>"
     : $page_title;
+    $page->content;
     $self->render_screen(
         screen_title => $screen_title,
         page_html => $page->to_html,
     );
 }
 
-1;
-
 __DATA__
 
 =head1 NAME 
@@ -70,24 +67,17 @@ __config/display.yaml__
 cache_pages:
 - HomePage
 __template/tt2/home_button.html__
-<!-- BEGIN home_button.html -->
 <a href="[% script_name %]?[% main_page %]" accesskey="h" title="Home Page">
 [% INCLUDE home_button_icon.html %]
 </a>
-<!-- END home_button.html -->
 __template/tt2/home_button_icon.html__
-<!-- BEGIN home_button_icon.html -->
 Home
-<!-- END home_button_icon.html -->
 __template/tt2/display_content.html__
-<!-- BEGIN display_content.html -->
 <div class="wiki">
 [% page_html -%]
 </div>
 [% INCLUDE display_changed_by.html %]
-<!-- END display_content.html -->
 __template/tt2/display_changed_by.html__
-<!-- BEGIN display_changed_by.html -->
 [% IF self.preferences.display_changed_by.value %]
 [% page = hub.pages.current %]
 <div style="background-color: #eee">
@@ -96,4 +86,3 @@ Last changed by [% page.edit_by_link %] at [% page.edit_time %]
 </em>
 </div>
 [% END %]
-<!-- END display_changed_by.html -->
